==> 0.1.zip: dmdirc-client/src/uk/org/ownage/dmdirc/parser/callbacks/interfaces/IPrivateMessage.java <==
/*
 * Copyright (c) 2006-2007 Chris Smith, Shane Mc Cormack
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 * SVN: $Id: IRCParser.java 178 2007-02-28 20:36:16Z ShaneMcC $
 */

package uk.org.ownage.dmdirc.parser.callbacks.interfaces;

import uk.org.ownage.dmdirc.parser.*;

/**
 * Called when a person sends a message to you directly (PM). 
 * sHost is the hostname of the person sending the message. (Can be a server or a person)<br>
 * cClient is null if user is a server, or not on any common channel.
 */
public interface IPrivateMessage extends ICallbackInterface {
	/**
	 * Called when a person sends a message to you directly (PM). 
	 * sHost is the hostname of the person sending the message. (Can be a server or a person)<br>
	 * cClient is null if user is a server, or not on any common channel.
	 * 
	 * @param tParser Reference to the parser object that made the callback.
	 * @param cClient Client who sent the message (may be null if no common channels or server)
	 * @param sMessage Message contents
	 * @param sHost Hostname of sender (or servername)
	 * @see IRCParser#addPrivateMessage
	 * @see IRCParser#delPrivateMessage
	 * @see IRCParser#callPrivateMessage
	 */
	public void onPrivateMessage(IRCParser tParser, ClientInfo cClient, String sMessage, String sHost );
}

==> 0.3.zip: dmdirc-client/src/uk/org/ownage/dmdirc/parser/callbacks/interfaces/IPrivateMessage.java <==
/*
 * Copyright (c) 2006-2007 Chris Smith, Shane Mc Cormack
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 * SVN: $Id$
 */

package uk.org.ownage.dmdirc.parser.callbacks.interfaces;

import uk.org.ownage.dmdirc.parser.IRCParser;

/**
 * Called when a person sends a message to you directly (PM). 
 * sHost is the hostname of the person sending the message. (Can be a server or a person)<br>
 * cClient is null if user is a server, or not on any common channel.
 */
public interface IPrivateMessage extends ICallbackInterface {
	/**
	 * Called when a person sends a message to you directly (PM). 
	 * sHost is the hostname of the person sending the message. (Can be a server or a person)<br>
	 * cClient is null if user is a server, or not on any common channel.
	 * 
	 * @param tParser Reference to the parser object that made the callback.
	 * @param sMessage Message contents
	 * @param sHost Hostname of sender (or servername)
	 * @see uk.org.ownage.dmdirc.parser.ProcessMessage#callPrivateMessage
	 */
	void onPrivateMessage(IRCParser tParser, String sMessage, String sHost);
}
